#!/bin/sh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2009. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/wmpm.sh BL_core_schema_8.0.6.1.03_20090320  232411
# (#) 
#
# @(#) wmpm.sh = startup WatchMark/Prospect process manager 'wmpm'
# USAGE:  wmpm.sh [ option ... ]
#   "option  = one of the following pairs options (default|other) --
#   append | reset   = append or delete log file(s) before starting
#   exec   | start   = for testing, launch 'wmpm' without using 'exec'
#   quiet  | trace   = for testing, set "WMPMTRACE=1" before launch
#   probe  | noprobe = for DataServers, set "XX_ENABLE_PROBE='ss'"
# NOTES:
#   for normal operations, use 'wmpm-init' to start|stop 'wmpm'
#   for testing/troubleshooting, use the example sequence below
# NOTES:
#   expects shell environment/settings from ~flexpm/.profile, etc
#   should be invoked via 'wmpm-init' or /etc/init.d/wmpm
# EXAMPLES:
#   $ wmpm-init stop ; wmpm-init start ;
# EXAMPLES:
#   : [a] to enable|disable DataServer Probe functions ...
#   $ wmpm-init start -- probe		;# enable probe (default)
#   $ wmpm-init start -- noprobe	;# disable probe
#   : [b] set environment first, then start with normal procedures
#   $ export DS_PROBE="no" ; wmpm-init start	;# disable probe
#   $ export DS_PROBE="90" ; wmpm-init start	;# enable, use "90" sec
# FILES:
#   ./pm/log/pm.log.YYYY-MM-DD	-- logfile for 'wmpm' itself
#   ./pm/log/wmpm.log		-- logfile for 'wmpm-init'
# SEE ALSO: ./pm/run/wmpm.sh, ./pm/adm/wmpm-init

#
##  give help if asked
#
    ToolName="`basename $0`"
    case $1 in
    -help|-usage)
        echo "?($ToolName) usage information -- " 1>&2
        grep "^# " $0 1>&2
        exit 2
        ;;
    esac
#
##  set handler for Interrupt/Quit Signals
#
    trap 'echo ; echo "** Interrupt **" ; exit ' 1 2 3 15

##  Check action/option args

    case $1 in
    -x ) shift ; set -x -- $@
    esac

    _exec_="exec"	;# start  |exec
    Logger="append"	;# append |reset
    Xtrace="quiet"	;# quiet  |trace

    echo "$@" | grep -s "reset" 1> /dev/null 2>&1 && Logger="reset"
    echo "$@" | grep -s "exec"  1> /dev/null 2>&1 && _exec_="exec"
    echo "$@" | grep -s "start" 1> /dev/null 2>&1 && _exec_=""

    export  WMPMTRACE		;#  for debugging
    export  QCTRACE		;#  for debugging
    export  DS_PROBE		;#  for "probe" function
    export  FX_ENABLE_PROBE     ;#  for "probe" function
    export  RS_ENABLE_PROBE     ;#  for "probe" function

    echo "$@" | grep -s "trace"   1> /dev/null 2>&1 && WMPMTRACE="1"
    echo "$@" | grep -s "quiet"   1> /dev/null 2>&1 && WMPMTRACE=

##  Set controls for "probe" for "fx|dd" DataServer -- see 'SEAde15065'

    echo "$@" | grep -s   "probe" 1> /dev/null 2>&1 &&  DS_PROBE="on"
    echo "$@" | grep -s "noprobe" 1> /dev/null 2>&1 &&  DS_PROBE="no"

    case ${DS_PROBE} in
    on  | '' )
	case ${FX_ENABLE_PROBE} in
	'' )
	    FX_ENABLE_PROBE="60"    ;# default to 60 seconds for "fx" if not set
            ;;
        esac
	case ${RS_ENABLE_PROBE} in
	'' )
	    RS_ENABLE_PROBE="180"   ;# default to 180 seconds for "rs" if not set
            ;;
        esac
        ;;
    [0-9]*   )
	export  FX_ENABLE_PROBE     ;# duration of "fx" probe cycle (seconds)
		FX_ENABLE_PROBE="${DS_PROBE}"

	export  RS_ENABLE_PROBE     ;# duration of "rs" probe cycle (seconds)
		RS_ENABLE_PROBE="${DS_PROBE}"
        ;;
    no  | *  )
	unset   FX_ENABLE_PROBE     ;# disable "fx" probe

	unset   RS_ENABLE_PROBE     ;# disable "rs" probe
        ;;
    esac

##  Set RGDS_HOME, where report group definition DataServer is started

    export  RGDS_HOME           ;#  contains DS definition for RG
    ##      RGDS_HOME="${PM_HOME}/ds/rg"	;## inherit, see .profile*

##  Set RG_SPOOLDIR, where report group processor will create report files

    export  RG_SPOOLDIR         ;#  'rg' report files
    ##      RG_SPOOLDIR="${PM_HOME}/rg/spool"	;## inherit, see .profile*

##  Set TASKLOG for Task Manager 'wmtm'

    export  TASKLOG             ;#  logfile for 'wmtm'
            TASKLOG="${RG_LOGS}/wmtm.log"

##  Setup log file

    When=`date +'%Y-%m-%d %H:%M:%S'`
    Date=`date +'%Y.%m.%d'`

    export  LogName             ;#  actual logfile for 'wmpm'
	    LogFile="${PM_LOGS}/pm.log"
	    LogDate="${PM_LOGS}/pm.log".${Date}

    export  ErrFile             ;#  actual errfile for 'wmpm'
	    ErrFile="${PM_LOGS}/pm.err"

##  Reset log files

    case $Logger in
    reset )
	chmod -f u+w ${TASKLOG} ; cp /dev/null ${TASKLOG}

	chmod -f u+w ${ErrFile} ; cp /dev/null ${ErrFile}
	chmod -f u+w ${LogFile} ; cp /dev/null ${LogFile}
	chmod -f u+w ${LogDate} ; cp /dev/null ${LogDate}

    esac
    case $Logger in
    *	)
	rm -f   ${PM_LOGS}/wmtm.log.${Date} ;	##  remove/reset link
	ln -s ../../rg/log/wmtm.log.${Date} \
	        ${PM_LOGS}/wmtm.log.${Date} ;
    esac

##  Check service PORT definition

    test -z "$WM_PM_PORT"  &&  WM_PM_PORT="${WM_PORT:=missing}"

    case ${WM_PM_PORT} in
    [0-9]* ) : ok ;;

    '' | missing | *  )
	warning "bad/missing WM_PM_PORT, check ~/.profile" ; exit 1
    esac

##  check low vm variable
 
    test -z "$WMPM_LOW_VM" && WMPM_LOW_VM="10"
    
##  Start 'wmpm' with appropriate control args

    cd ${FLEXPM_HOME}/pm/run

    unset ENV CDPATH	;#  turn off for 'wmpm.sh' (stop ksh reading ${ENV} etc)

##  echo command strings
    echo 1>&2 + \
    $_exec_  \
	wmpm \
	-service   ${PM_PORT} \
	-dsTimeout ${PM_DS_TIMEOUT-900} \
    -lowVM  ${WMPM_LOW_VM} \
	-l  ${LogFile} \
	...



## chech if pm.err does exist
if test -f ${ErrFile}
then 
  mv ${ErrFile} ${ErrFile}.${Date}
fi
	
##  exec command itself
    $_exec_  \
	wmpm \
	-service   ${PM_PORT} \
	-dsTimeout ${PM_DS_TIMEOUT-900} \
    -lowVM  ${WMPM_LOW_VM} \
	-l  ${LogFile} \
	1>> ${ErrFile} 2>&1 \
	&
#.
